@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2019-2020 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2019-2023 Kevin B. Hendricks, Stratford Ontario Canada
 **
 **  This file is part of PageEdit.
 **
@@ -38,8 +38,12 @@
 #include "Viewer.h"
 #include "Inspector.h"
 #include "ElementIndex.h"
+#include "ClipEditorModel.h"
 #include "webviewprinter.h"
 
+
+class ClipsWindow;
+class ClipEditor;
 class WebViewEdit;
 class Inspector;
 class QWebEngineView;
@@ -96,11 +100,18 @@ public slots:
     void SetZoomFactor(float factor);
     void EmitGoToPreviewLocationRequest();
     void InspectPreviewPage();
+    void EditClips();
+    void OpenClipsWindow();
+    void ToggleClipToolbar();
     void SelectAllPreview();
     void CopyPreview();
     void ReloadPreview();
     void ShowMessageOnStatusBar(const QString &message = "", int millisecond_duration = STATUSBAR_MSG_DISPLAY_TIME);
     void AboutPageEdit();
+    void PasteClipEntriesIntoTarget(QList<ClipEditorModel::clipEntry *>clips);
+    void PasteClipNumberIntoTarget(int clip_number);
+    void UpdateClipsUI();
+    
 
     // Navigation Slots
     void EditNext();
@@ -196,6 +207,7 @@ private:
     void LoadSettings();
     void SaveSettings();
     void AllowSaveIfModified();
+    void UpdateClipButton(QAction *ui_action);
     void ConnectSignalsToSlots();
 
     WebViewEdit *m_WebView;
@@ -226,6 +238,7 @@ private:
     QString m_Base;
     int m_ListPtr;
     bool m_UpdatePageInProgress;
+    QStringList m_CSSList;
     QStringList m_MediaList;
     QStringList m_MediaKind;
     QString m_MediaBase;
@@ -235,6 +248,9 @@ private:
     WebViewPrinter *m_WebViewPrinter;
 
     QList<ElementIndex> m_LastLocation;
+    ClipsWindow* m_Clips;
+    ClipEditor*  m_ClipEditor;
+    QList<QAction*> m_clactions;
     int m_LastPtr;
 
     Ui::MainWindow ui;
