@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2016-2022 Kevin B. Hendricks, Stratford, ON
+**  Copyright (C) 2016-2023 Kevin B. Hendricks, Stratford, ON
 **  Copyright (C) 2011-2013 John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012-2013 Dave Heiland
 **
@@ -41,6 +41,8 @@ static QString KEY_ORIGINAL_UI_FONT = SETTINGS_GROUP + "/" + "original_ui_font";
 static QString KEY_HIGHDPI_SETTING = SETTINGS_GROUP + "/" + "high_dpi";
 static QString KEY_DISABLEGPU_SETTING = SETTINGS_GROUP + "/" + "disable_gpu";
 static QString KEY_PREVIEW_DARK_IN_DM = SETTINGS_GROUP + "/" + "preview_dark_in_dm";
+static QString KEY_PRINT_PREVIEW_DPI_SETTING = SETTINGS_GROUP + "/" + "print_preview_dpi";
+static QString KEY_PRINT_DPI_SETTING = SETTINGS_GROUP + "/" + "print_dpi";
 
 static QString KEY_SPELL_CHECK = SETTINGS_GROUP + "/" + "spellcheck";
 static QString KEY_ZOOM_IMAGE = SETTINGS_GROUP + "/" + "zoom_image";
@@ -125,6 +127,20 @@ int SettingsStore::previewDark()
     return value(KEY_PREVIEW_DARK_IN_DM, 1).toInt();
 }
 
+
+int SettingsStore::printPreviewDPI()
+{
+    clearSettingsGroup();
+    return value(KEY_PRINT_PREVIEW_DPI_SETTING, 96).toInt();
+}
+
+int SettingsStore::printDPI()
+{
+    clearSettingsGroup();
+    return value(KEY_PRINT_DPI_SETTING, 300).toInt();
+}
+
+
 #if 0
 bool SettingsStore::spellCheck()
 {
@@ -272,6 +288,18 @@ void SettingsStore::setPreviewDark(int enabled)
     setValue(KEY_PREVIEW_DARK_IN_DM, enabled);
 }
 
+void SettingsStore::setPrintPreviewDPI(int dpi)
+{
+    clearSettingsGroup();
+    setValue(KEY_PRINT_PREVIEW_DPI_SETTING, dpi);
+}
+
+void SettingsStore::setPrintDPI(int dpi)
+{
+    clearSettingsGroup();
+    setValue(KEY_PRINT_DPI_SETTING, dpi);
+}
+
 #if 0
 void SettingsStore::setSpellCheck(bool enabled)
 {
