@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2019-2020  Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2019-2023  Kevin B. Hendricks, Stratford Ontario Canada
 **
 **  This file is part of PageEdit.
 **
@@ -44,12 +44,13 @@
 
 #include "Utility.h"
 #include "SettingsStore.h"
+#include "WebProfileMgr.h"
 #include "UIDictionary.h"
 
 #include "WebPageEdit.h"
 #include "WebViewEdit.h"
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
     #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
 #else
     #define QT_ENUM_SKIPEMPTYPARTS QString::SkipEmptyParts
@@ -106,8 +107,7 @@ struct SetToHTMLResultFunctor {
 
 WebViewEdit::WebViewEdit(QWidget *parent)
     : QWebEngineView(parent),
-      m_ViewWebPage(new WebPageEdit(this)),
-      c_jQuery(Utility::ReadUnicodeTextFile(":/javascript/jquery-2.2.4.min.js")),
+      c_jQuery(Utility::ReadUnicodeTextFile(":/javascript/jquery-3.6.4.min.js")),
       c_jQueryScrollTo(Utility::ReadUnicodeTextFile(":/javascript/jquery.scrollTo-2.1.2-min.js")),
       c_GetCaretLocation(Utility::ReadUnicodeTextFile(":/javascript/book_view_current_location.js")),
       c_GetBlock(Utility::ReadUnicodeTextFile(":/javascript/get_block.js")),
@@ -122,22 +122,12 @@ WebViewEdit::WebViewEdit(QWidget *parent)
       m_LoadOkay(false),
       m_menu(new QMenu(this))
 {
+    QWebEngineProfile* profile = WebProfileMgr::instance()->GetPreviewProfile();
+    m_ViewWebPage = new WebPageEdit(profile, this);
     setPage(m_ViewWebPage);
     // Set the Zoom factor but be sure no signals are set because of this.
     SettingsStore settings;
     SetCurrentZoomFactor(settings.zoomPreview());
-    page()->settings()->setAttribute(QWebEngineSettings::ErrorPageEnabled, false);
-    page()->settings()->setDefaultTextEncoding("UTF-8");
-    page()->settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, (settings.javascriptOn() == 1));
-    page()->settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, (settings.remoteOn() == 1));
-    // Enable local-storage for epub3
-    page()->settings()->setAttribute(QWebEngineSettings::LocalStorageEnabled, true);
-    QString localStorePath = Utility::DefinePrefsDir() + "/local-storage";
-    QDir storageDir(localStorePath);
-    if (!storageDir.exists()) {
-        storageDir.mkpath(localStorePath);
-    }
-    page()->profile()->setPersistentStoragePath(localStorePath);
     m_dictionaries = UIDictionary::GetUIDictionaries();
     ConnectSignalsToSlots();
 }
@@ -515,9 +505,14 @@ bool WebViewEdit::InsertTagAttribute(const QString &element_name, const QString
         selected_text = attribute_value;
     }
 
+    QString safe_text(selected_text);
+    safe_text.replace("&","&amp;");
+    safe_text.replace("<", "&lt;");
+    safe_text.replace(">", "&gt;");
+
     // Just prepend and append the tag pairs to the text
     const QString html = "<" + element_name + " " + attribute_name + "=\"" + 
-	                  attribute_value + "\">" + selected_text + "</" + element_name + ">";
+	                  attribute_value + "\">" + safe_text + "</" + element_name + ">";
     bool insert_ok = InsertHtml(html);
 
     // We will have lost our selection from the insert - viewable text hasn't changed
@@ -813,6 +808,40 @@ bool WebViewEdit::ExecuteCaretUpdate(const QString &caret_update)
     return false;
 }
 
+bool WebViewEdit::PasteClipNumber(int clip_number)
+{
+    ClipEditorModel::clipEntry *clip = ClipEditorModel::instance()->GetEntryFromNumber(clip_number);
+    if (!clip) {
+        return false;
+    }
+    PasteClipEntry(clip);
+    return true;
+}
+
+bool WebViewEdit::PasteClipEntries(const QList<ClipEditorModel::clipEntry *> &clips)
+{
+    bool applied = false;
+    foreach(ClipEditorModel::clipEntry * clip, clips) {
+        applied = applied || PasteClipEntry(clip);
+    }
+    return applied;
+}
+
+bool WebViewEdit::PasteClipEntry(ClipEditorModel::clipEntry *clip)
+{
+    if (!clip || clip->text.isEmpty()) {
+        return false;
+    }
+    QString text = clip->text;
+
+    if (text.contains("\\1")) {
+        text.replace("\\1", GetSelectedText());
+    }
+    InsertHtml(text);
+    return true;
+}
+
+
 void WebViewEdit::ConnectSignalsToSlots()
 {
     connect(page(), SIGNAL(loadFinished(bool)), this, SLOT(UpdateFinishedState(bool)));
